@@ -1,7 +1,8 @@
 import os
 import sys
 from time import sleep
-from getch import _Getch
+
+from simple_csv_reader.getch import _Getch
 
 class CliHelper:
 
